@@ -36,7 +36,7 @@ under the same terms as Perl itself.
 
 =cut
 
-our $VERSION = '0.039'; # VERSION
+our $VERSION = '0.040'; # VERSION
 
 use Mouse;
 use FileHandle;
@@ -63,6 +63,11 @@ sub _finish_stanza
     return;
   }
 
+  if (!defined $current->{name}) {
+    warn "term without a name tag ignored: ", $current->{id}, "\n";
+    return;
+  }
+
   if (!defined $current->{id}) {
     die_line $filename,  $current->{line}, "stanza has no id\n";
     return;
